/*
    PPPTCP -- an implementation of PPP over TCP, with possible encryption.

    Copyright (C) 1997  Sam Lantinga		(slouken@devolution.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* The address-based authentication model with no encryption */

#include <stdio.h>

#include "version.h"
#include "types.h"
#include "packet.h"
#include "auth.h"

#undef USE_ENCRYPTION

int authargs(int argc, char *argv[])
{
	return(argc);
}
/* The protocol:
	The client sends a version byte.
	If the server supports the version, it returns the byte and 'Y'
	If the server doesn't support the version, it returns the byte and 'N'
	If the high bit of the byte is set, encryption is supported.
	If the version byte (without encryption) is 0x7F, then it indicates
	extended version/option negotiation, currently undefined.
*/
int authenticate(char *isclient, int netfd)
{
	char version[2];

	if ( isclient ) {
		/* Send version */
		version[0] = PPPTCP_VERSION;
#ifdef USE_ENCRYPTION
		version[0] |= 0x80;
#endif
		write(netfd, version, 1);

		/* Wait for reply */
		version[1] = PROTO_UNSUPPORTED;	/* In case read() fails */
		read(netfd, version, 2);
	} else {
		/* Wait for client to send version */
		read(netfd, version, 1);

		/* Check it and send it back */
#ifdef USE_ENCRYPTION
		version[0] &= 0x7F;
#endif
		if ( version[0] == PPPTCP_VERSION )
			version[1] = PROTO_SUPPORTED;
		else
			version[1] = PROTO_UNSUPPORTED;
		write(netfd, version, 2);
	}
	/* Currently we don't handle extended option negotiation */
	if ( (version[1] != PROTO_SUPPORTED) ||
				 ((version[0]&0x7F) != PPPTCP_VERSION) ) {
		fprintf(stderr,
	"PPPTCP protocol version %d (unencrypted) not supported by remote\n",
								PPPTCP_VERSION);
		return(-1);
	}
	return(0);
}

/* Stub encryption/decryption routines */
int packet_encrypt(packet *pkt)
{
	return(pkt->len);
}
int packet_decrypt(packet *pkt)
{
	return(pkt->len);
}
